ABlog v0.2 released
===================

.. post:: Aug 31, 2014
   :author: Ahmet
   :category: Release
   :location: SF

ABlog v0.2 is released. This version comes with several new features:

  * You can post a document multiple times, see :ref:`posting-sections`
    for details.

  * You can make note of updates in a post using :rst:dir:`update`
    directive.

  * Blog feeds for authors, locations, categories, tags, and years
    can be enabled using :confval:`blog_feed_archives` configuration
    variable.

  * Blog Feeds can be made full text using :confval:`blog_feed_fulltext`
    configuration variable.

  * Recent posts side bar includes month and day of the posts.

ABlog v0.2.1 released
---------------------

.. post:: Sep 1, 2014
   :author: Ahmet
   :category: Release
   :location: SF

ABlog v0.2.1 is a bug fix release that solves duplicated content
problem in full text atom feeds.

ABlog v0.2.2 released
---------------------

.. post:: Sep 3, 2014
   :author: Ahmet
   :category: Release
   :location: SF

ABlog v0.2.2 is a bug fix release that solves broken links problem
in post lists (:issue:`12`).

ABlog v0.2.3 released
---------------------

.. post:: Sep 10, 2014
   :author: Ahmet
   :category: Release
   :location: SF

ABlog v0.2.3 is a bug fix release that solves broken links (:issue:`13`)
and non-unique post IDs problems atom feeds.
